@@ -107,6 +107,7 @@ ComicApplet::ComicApplet( QObject *parent, const QVariantList &args )
       mShowComicTitle( false ),
       mShowComicIdentifier( false ),
       mFullViewWidget( 0 ),
+      mEngine( 0 ),
       mFrame( 0 ),
       mFadingItem( 0 ),
       mPrevButton( 0 ),
@@ -162,12 +163,12 @@ void ComicApplet::init()
     mActions.append( mActionScaleContent );
     connect( mActionScaleContent, SIGNAL( triggered( bool ) ), this , SLOT( slotScaleToContent() ) );
 
-    updateComic();
-
-    connect( Solid::Networking::notifier(), SIGNAL( statusChanged( Solid::Networking::Status ) ),
-             this, SLOT( networkStatusChanged( Solid::Networking::Status ) ) );
-
     connect( this, SIGNAL( geometryChanged() ), this, SLOT( slotSizeChanged() ) );
+
+    mEngine = dataEngine( "comic" );
+    connect( mEngine, SIGNAL( isBusy( bool ) ), this, SLOT( setBusy( bool ) ) );
+
+    updateComic();
 }
 
 ComicApplet::~ComicApplet()
@@ -177,15 +178,13 @@ ComicApplet::~ComicApplet()
 
 void ComicApplet::dataUpdated( const QString&, const Plasma::DataEngine::Data &data )
 {
-    setBusy( false );
-
     if ( data[ "Error" ].toBool() ) {
         if ( !data[ "Previous identifier suffix" ].toString().isEmpty() ) {
             updateComic( data[ "Previous identifier suffix" ].toString() );
         } else {
             setConfigurationRequired( true );
-            return;
         }
+        return;
     }
 
     mImage = data[ "Image" ].value<QImage>();
@@ -220,9 +219,9 @@ void ComicApplet::dataUpdated( const QString&, const Plasma::DataEngine::Data &d
     updateContextMenu();
 
     Plasma::ToolTipContent toolTipData;
-    toolTipData.setAutohide( false );
     if ( !mAdditionalText.isEmpty() ) {
         toolTipData = Plasma::ToolTipContent( mAdditionalText, QString() );
+        toolTipData.setAutohide( false );
     }
     Plasma::ToolTipManager::self()->setContent( this, toolTipData );
 
@@ -278,12 +277,6 @@ void ComicApplet::applyConfig()
     }
 }
 
-void ComicApplet::networkStatusChanged( Solid::Networking::Status status )
-{
-    if ( status == Solid::Networking::Connected )
-        updateComic();
-}
-
 void ComicApplet::checkDayChanged()
 {
     if ( ( mCurrentDay != QDate::currentDate() ) || mImage.isNull() )
@@ -665,26 +658,19 @@ void ComicApplet::wheelEvent( QGraphicsSceneWheelEvent *event )
 
 void ComicApplet::updateComic( const QString &identifierSuffix )
 {
-    Plasma::DataEngine *engine = dataEngine( "comic" );
-    if ( !engine )
-        return;
+    mEngine = dataEngine( "comic" );
 
-    setConfigurationRequired( mComicIdentifier.isEmpty() );
-    if ( !mComicIdentifier.isEmpty() ) {
-        setBusy( true );
+    if ( !mComicIdentifier.isEmpty() && mEngine && mEngine->isValid() ) {
         const QString identifier = mComicIdentifier + ':' + identifierSuffix;
+        mEngine->disconnectSource( identifier, this );
+        mEngine->connectSource( identifier, this );
+        const Plasma::DataEngine::Data data = mEngine->query( identifier );
 
-        engine->disconnectSource( identifier, this );
-        engine->connectSource( identifier, this );
-        const Plasma::DataEngine::Data data = engine->query( identifier );
-        if ( data[ "Error" ].toBool() ) {
-            if ( !data[ "Previous identifier suffix" ].toString().isEmpty() ) {
-                updateComic( data[ "Previous identifier suffix" ].toString() );
-            } else {
-                setConfigurationRequired( true );
-            }
-             setBusy( false );
+        if ( data[ "Error" ].toBool() && data[ "Previous identifier suffix" ].toString().isEmpty() ) {
+            setConfigurationRequired( true );
         }
+    } else {
+        setConfigurationRequired( true );
     }
 }
 
