@@ -245,7 +245,8 @@ ComicProviderWrapper::ComicProviderWrapper( ComicProviderKross *parent )
       mProvider( parent ),
       mKrossImage( 0 ),
       mPackage( 0 ),
-      mRequests( 0 )
+      mRequests( 0 ),
+      mIdentifierSpecified( false )
 {
     QTimer::singleShot( 0, this, SLOT( init() ) );
 }
@@ -280,6 +281,7 @@ void ComicProviderWrapper::init()
                     mAction->trigger();
                     mFunctions = mAction->functionNames();
 
+                    mIdentifierSpecified = !mProvider->isCurrent();
                     setIdentifierToDefault();
                     callFunction( "init" );
                 }
@@ -362,26 +364,30 @@ void ComicProviderWrapper::checkIdentifier( QVariant *identifier )
 {
     switch ( identifierType() ) {
     case DateIdentifier:
+        if ( !mLastIdentifier.isNull() && !identifier->isNull() &&
+             ( !mIdentifierSpecified || identifier->toDate() > mLastIdentifier.toDate() ) ) {
+            *identifier = mLastIdentifier;
+        }
         if ( !mFirstIdentifier.isNull() && !identifier->isNull() &&
              identifier->toDate() < mFirstIdentifier.toDate() ) {
             *identifier = mFirstIdentifier;
         }
-        if ( !mLastIdentifier.isNull() && !identifier->isNull() &&
-             identifier->toDate() > mLastIdentifier.toDate() ) {
-            *identifier = mLastIdentifier;
-        }
         break;
     case NumberIdentifier:
-        //if the identifier is 0 make it the lastIdentifier
-        if ( !mFirstIdentifier.isNull() && !identifier->isNull() &&
-             identifier->toInt() < mFirstIdentifier.toInt() && identifier->toInt() ) {
-            *identifier = mFirstIdentifier;
-        } else if ( !mLastIdentifier.isNull() && !identifier->isNull() &&
-           ( identifier->toInt() > mLastIdentifier.toInt() || ( identifier->toInt() == 0 ) ) ) {
+        if ( !mLastIdentifier.isNull() && !identifier->isNull() &&
+           ( !mIdentifierSpecified || identifier->toInt() > mLastIdentifier.toInt() ) ) {
             *identifier = mLastIdentifier;
         }
+        if ( !mFirstIdentifier.isNull() && !identifier->isNull() &&
+             identifier->toInt() < mFirstIdentifier.toInt() ) {
+            *identifier = mFirstIdentifier;
+        }
         break;
     case StringIdentifier:
+        if ( !mLastIdentifier.isNull() && !mLastIdentifier.toString().isEmpty() &&
+             !mIdentifierSpecified ) {
+            *identifier = mLastIdentifier;
+        }
         break;
     }
 }
@@ -403,6 +409,21 @@ void ComicProviderWrapper::setIdentifierToDefault()
     }
 }
 
+bool ComicProviderWrapper::identifierSpecified() const
+{
+    return mIdentifierSpecified;
+}
+
+QString ComicProviderWrapper::textCodec() const
+{
+    return QString( mTextCodec );
+}
+
+void ComicProviderWrapper::setTextCodec( const QString &textCodec )
+{
+    mTextCodec = textCodec.toAscii();
+}
+
 QString ComicProviderWrapper::comicAuthor() const
 {
     return mProvider->comicAuthor();
@@ -593,7 +614,13 @@ void ComicProviderWrapper::pageRetrieved( int id, const QByteArray &data )
             finished();
         }
     } else {
-        QTextCodec *codec = QTextCodec::codecForHtml( data );
+        QTextCodec *codec = 0;
+        if ( !mTextCodec.isEmpty() ) {
+            codec = QTextCodec::codecForName( mTextCodec );
+        }
+        if ( !codec ) {
+            codec = QTextCodec::codecForHtml( data );
+        }
         QString html = codec->toUnicode( data );
 
         callFunction( "pageRetrieved", QVariantList() << id << html );
